script_type="up"
dev="tun13"
foreign_option_1="dhcp-option DNS 1234:567:89::ab:cdef"

TEST_TITLE="Single IPv6 DNS Server (Compact) (Part 2)"
TEST_BUSCTL_CALLED=1
TEST_BUSCTL_DNS="1 10 16 18 52 5 103 0 137 0 0 0 0 0 0 0 171 205 239"
