script_type="up"
dev="tun14"
foreign_option_1="dhcp-option DNS 20a0::1"

TEST_TITLE="Single IPv6 DNS Server (Compact) (Part 3)"
TEST_BUSCTL_CALLED=1
TEST_BUSCTL_DNS="1 10 16 32 160 0 0 0 0 0 0 0 0 0 0 0 0 0 1"
