script_type="up"
dev="tun05"
foreign_option_1="dhcp-option ADAPTER_DOMAIN_SUFFIX example.org"

TEST_TITLE="DNS Doamin using ADAPTER_DOMAIN_SUFFIX"
TEST_BUSCTL_CALLED=1
TEST_BUSCTL_DOMAINS="1 example.org false"
